@@ -29,6 +29,7 @@ class ScoreComparer:
         compute a standard deviation of all of the stat categories.
     """
     def __init__(self, cfg, scorer, lg_lineups):
+        self.logger = logging.getLogger()
         self.cfg = cfg
         self.scorer = scorer
         self.opp_sum = None
@@ -88,6 +89,8 @@ class ScoreComparer:
             # Lineup could be empty if all players were moved to the bench
             if len(df.index) > 0:
                 score_sum = self.scorer.summarize(df)
+                self.logger.info(df.name.to_string())
+                self.logger.info(score_sum)
                 scores.append(score_sum)
         df = pd.DataFrame(scores)
         return df.agg([agg])
@@ -171,7 +174,7 @@ class ManagerBot:
             return
 
         ir = []
-        roster = self._get_orig_roster()
+        roster = self.fetch_cur_lineup()
         for plyr in roster:
             if plyr['status'].startswith(self.lg_statics.ir_name) or \
                     plyr['status'] == 'COVID-19':
@@ -185,12 +188,19 @@ class ManagerBot:
                         del self.bench[idx]
                         break
 
-        if len(ir) <= self.lg_statics.ir_spots:
-            self.injury_reserve = ir
-        else:
-            assert(False), "Need to implement pruning of IR"
+        ir.sort(key=lambda p: p['percent_owned'], reverse=True)
+        while len(ir) > self.lg_statics.ir_spots:
+            # We have more IR players than IR spots.  We trim them by removing
+            # the ones that are the least owned.  We have already sorted the
+            # list, so we trim the last element.
+            rm_plyr = ir.pop()
+            # This could expand the bench past the number of allowed players.
+            # We will trim this down the correct number later.
+            plyr_from_pool = self.ppool[self.ppool['player_id'] == rm_plyr['player_id']]
+            self.bench.append(plyr_from_pool.iloc(0)[0])
+        self.injury_reserve = ir
 
-    def move_non_available_players(self):
+    def move_non_available_players(self, ignore_status):
         """Remove any player that has a status (e.g. DTD, SUSP, etc.).
 
         If the player is important enough, they will be added back to the bench
@@ -198,13 +208,14 @@ class ManagerBot:
         """
         roster = self._get_orig_roster()
         for plyr in roster:
-            if plyr['status'].strip() != '':
+            status = plyr['status'].strip()
+            if status != '' and (not ignore_status or 'IL' == status):
                 for idx, lp in enumerate(self.lineup):
                     if lp['player_id'] == plyr['player_id']:
                         self.logger.info(
                             "Moving {} out of the starting lineup because "
                             "they are not available ({})".format(
-                                plyr['name'], plyr['status']))
+                                plyr['name'], status))
                         del self.lineup[idx]
                         break
 
@@ -289,6 +300,7 @@ class ManagerBot:
         if self.ppool is None:
             plyr_pool = self.fetch_free_agents() + self.fetch_cur_lineup()
             self.ppool = self._call_predict(plyr_pool, fail_on_missing=False)
+            self._filter_excluded_players()
 
     def fetch_free_agents(self):
         def loader():
@@ -450,10 +462,24 @@ class ManagerBot:
 
     def _get_locked_players_list(self):
         locked_file = self.cfg['LineupOptimizer']['lockPlayerFile']
-        if locked_file != "":
-            if not os.path.isfile(locked_file):
-                raise RuntimeError("Could not open locked file: {}".format(locked_file))
-            with open(locked_file) as f:
+        return self._get_player_list(locked_file)
+
+    def _get_exclude_players_list(self):
+        exclude_file = self.cfg['LineupOptimizer']['excludePlayerFile']
+        return self._get_player_list(exclude_file)
+
+    def _filter_excluded_players(self):
+        for plyr_name in self._get_exclude_players_list():
+            self.logger.info(f"Removing {plyr_name} from player pool")
+            self.logger.info(f"Player pool size (before) = {len(self.ppool.index)}")
+            self.ppool = self.ppool[self.ppool['name'] != plyr_name]
+            self.logger.info(f"Player pool size (after) = {len(self.ppool.index)}")
+
+    def _get_player_list(self, file_name):
+        if file_name != "":
+            if not os.path.isfile(file_name):
+                raise RuntimeError("Could not open file: {}".format(file_name))
+            with open(file_name) as f:
                 return [p.strip() for p in f.readlines()]
         else:
             return []
